#ifndef CONSTANTS_H
#define CONSTANTS_H

#include <QString>

class Constants {

public:

    static const char *VERSION;
    static const char *NAME;
    static const char *UNIX_NAME;
    static const char *ORG_NAME;
    static const char *ORG_DOMAIN;
    static const char *WEBSITE;
    static const char *EMAIL;

};

#endif
